@@ -9,17 +9,17 @@
   (:export
    #:resolve-host-ipaddr #:bogomips #:mkstemp #:mkdtemp
    #:stream-lock #:with-stream-lock #:duplicate-handle #:copy-file
-   #:file-owner #:physical-memory
+   #:file-owner #:physical-memory #:stream-options #+unix #:string-time
    #+(or :win32 :cygwin) #:file-properties #+unix #:make-xterm-io-stream
    #:priority #:process-id #:openlog #:setlogmask #:syslog #:closelog
    #:getpgid #:setpgrp #:getsid #:setsid #:setpgid #:kill #:sync
    #:erf #:erfc #:j0 #:j1 #:jn #:y0 #:y1 #:yn #:gamma #:lgamma))
 
-(setf (package-lock "EXT") nil)
-(use-package '("POSIX") "EXT")
-(ext:re-export "POSIX" "EXT")
 (pushnew :syscalls *features*)
-(in-package "POSIX")
+(in-package #:posix)
+
+(setf (documentation (find-package '#:posix) 'sys::impnotes) "syscalls")
+(setf (documentation 'sys::process-id 'sys::impnotes) "process-id")
 
 ;;; ============================================================
 #+unix (progn
@@ -28,6 +28,14 @@
   type user id line pid host tv)
 )
 ;;; ============================================================
+#+unix (progn
+(export '(getuid getgid geteuid getegid))
+(defsetf getuid posix::%setuid)
+(defsetf getgid posix::%setgid)
+(defsetf geteuid posix::%seteuid)
+(defsetf getegid posix::%setegid)
+)
+;;; ============================================================
 (defmacro with-stream-lock ((stream &rest options) &body body)
   "Lock the stream, execute the body, unlock the stream."
   `(unwind-protect (progn (stream-lock ,stream t ,@options) ,@body)
@@ -56,10 +64,10 @@
 #+unix (export '(crypt encrypt setkey mknod))
 
 #+unix
-(defstruct (user-data (:constructor
-                       make-user-data (login-id passwd uid gid full-name
+(defstruct (user-info (:constructor
+                       make-user-info (login-id passwd uid gid full-name
                                        home-dir shell)))
-  "see getwnam(2) for details"
+  "see <pwd.h> for details"
   (login-id  "" :type simple-string :read-only t)
   (passwd    "" :type simple-string :read-only t)
   (uid        0 :type (unsigned-byte 32) :read-only t)
@@ -67,6 +75,13 @@
   (full-name "" :type simple-string :read-only t)
   (home-dir  "" :type simple-string :read-only t)
   (shell     "" :type simple-string :read-only t))
+
+#+unix
+(defstruct (group-info (:constructor make-group-info (name gid members)))
+  "see <grp.h> for details"
+  (name    "" :type simple-string :read-only t)
+  (gid      0 :type (unsigned-byte 32) :read-only t)
+  (members () :type list :read-only t))
 ;;; ============================================================
 (export '(set-file-stat convert-mode umask))
 
@@ -87,6 +102,8 @@
   (blocks  nil :type (or null (unsigned-byte 32)) :read-only t)
   (atime     0 :type (integer 0) :read-only t)
   (mtime     0 :type (integer 0) :read-only t)
+  ;; win32: creation time
+  ;; unix: inode change time
   (ctime     0 :type (integer 0) :read-only t))
 
 ;;; ============================================================
@@ -251,6 +268,90 @@
             (values (memstat-total-physical mem-stat)
                     (memstat-avail-physical mem-stat))))
 
+;;;--------------------------------------------------------------------------
+;;; service / port map
+(defstruct (service (:constructor make-service (name aliases port proto)))
+  ;; see getservent(3)
+  (name     "" :type string)
+  (aliases  () :type list) ; list of strings
+  (port      0 :type integer)
+  (proto "tcp" :type string))
+
+(unless (fboundp 'service)
+(defvar *services*)
+(defvar *services-file*
+  #+unix "/etc/services"
+  #+win32 (string-concat (getenv "WINDIR") "/system32/drivers/etc/services"))
+(defun service (&optional service-name protocol)
+  (unless (boundp '*services*)
+    (setq *services*
+          (with-open-file (in *services-file* :direction :input
+                           #+UNICODE :external-format #+UNICODE 'charset:UTF-8)
+            (loop :with ret :for line = (read-line in nil nil) :while line :do
+              ;; Remove trailing comments.
+              (let ((i (position #\# line)))
+                (when i (setq line (subseq line 0 i))))
+              ;; Split into whitespace separated fields.
+              (let ((fields '()))
+                (let ((i 0))
+                  (loop
+                    (let ((i1 (position-if-not #'sys::whitespacep
+                                               line :start i)))
+                      (unless i1 (return))
+                      (let ((i2 (or (position-if #'sys::whitespacep
+                                                 line :start i1)
+                                    (length line))))
+                        (push (subseq line i1 i2) fields)
+                        (setq i i2)))))
+                (setq fields (nreverse fields))
+                (when fields
+                  ;; Split second field, of the form "port/proto".
+                  (let* ((port+proto (second fields))
+                         (i (position #\/ port+proto)))
+                    (when i
+                      (push
+                       (make-service (first fields)
+                                     (cddr fields)
+                                     (parse-integer (subseq port+proto 0 i))
+                                     (subseq port+proto (1+ i)))
+                       ret)))))
+              :finally (return (nreverse ret))))))
+  (etypecase service-name
+    (null (mapcar #'copy-service *services*))
+    (string
+     (or (find-if #'(lambda (se)
+                      (and (or (string-equal (service-name se) service-name)
+                               (find service-name (service-aliases se)
+                                     :test #'string-equal))
+                           (or (null protocol)
+                               (string-equal (service-proto se) protocol))))
+                  *services*)
+         (error (SYS::TEXT "service does not exist: ~A/~A")
+                service-name protocol)))
+    (integer
+     (or (find-if #'(lambda (se)
+                      (and (= (service-port se) service-name)
+                           (or (null protocol)
+                               (string-equal (service-proto se) protocol))))
+                  *services*)
+         (error (SYS::TEXT "service does not exist: ~A/~A")
+                service-name protocol)))))
+)
+(without-package-lock ("SOCKET")
+  (sys::deprecate (intern "SOCKET-SERVICE-PORT" "SOCKET") 'service
+                  (lambda (&optional sn pr)
+                    (let ((ret (service sn pr)))
+                      (if (listp ret)
+                          (mapcar (lambda (se)
+                                    (vector (service-name se)
+                                            (service-aliases se)
+                                            (service-port se)
+                                            (service-proto se)))
+                                  ret)
+                          (values (service-name ret) (service-aliases ret)
+                                  (service-port ret) (service-proto ret)))))))
+(without-package-lock ("EXT")
+  (export (find-symbol "SOCKET-SERVICE-PORT" "SOCKET") "EXT"))
 
 ;;;--------------------------------------------------------------------------
 #+unix
@@ -277,6 +378,10 @@
         (remove-method #'close (find-method #'close '(:after) `((eql ,xio))))))
     xio))
 
-;;; restore locks
+;;;--------------------------------------------------------------------------
+(setf (package-lock "EXT") nil)
+(use-package '("POSIX") "EXT")
+(without-package-lock ("SYS") (shadow '("VERSION") "SYS"))
+(ext:re-export "POSIX" "EXT")
 (pushnew "POSIX" custom:*system-package-list* :test #'string=)
 (setf (package-lock custom:*system-package-list*) t)
