@@ -46,31 +46,27 @@ to print the corresponding values, or T for all of them.")
   (dolist (sym (apropos-list string package))
     (format t "~&~s~40t" sym)
     (when (fboundp sym)
-      (write-string "   ")
+      #1=(write-string "   ")   ; spacer
       (write-string (fbound-string sym))
       (when (apropos-do-more :function)
         (format t " [~s]" (fdefinition sym))))
     (when (symbol-macro-expand sym)
-      (write-string "   ")
-      (write-string (TEXT "symbol-macro")))
+      #1# (write-string (TEXT "symbol-macro")))
     (when (boundp sym)
-      (write-string "   ")
-      (if (constantp sym)
-        (write-string (TEXT "constant"))
-        (write-string (TEXT "variable")))
+      #1# (if (constantp sym)
+            (write-string (TEXT "constant"))
+            (write-string (TEXT "variable")))
       (when (apropos-do-more :variable)
         (format t " [~s]" (symbol-value sym))))
     (let ((type (or (get sym 'system::type-symbol)
                     (get sym 'system::defstruct-description))))
       (when type
-        (write-string "   ")
-        (write-string (TEXT "type"))
+        #1# (write-string (TEXT "type"))
         (when (apropos-do-more :type)
           (format t " [~s]" type))))
     (let ((class (get sym 'clos::closclass)))
       (when class
-        (write-string "   ")
-        (write-string (TEXT "class"))
+        #1# (write-string (TEXT "class"))
         (when (apropos-do-more :class)
           (format t " [~s]" class))))
     (elastic-newline))
@@ -105,6 +101,14 @@ to print the corresponding values, or T for all of them.")
         (terpri stream)
         (format stream (TEXT "No slots."))))))
 
+(defun launch-doc (obj type stream name)
+  (when (zerop *describe-nesting*)
+    (let ((doc (documentation obj type)))
+      (when doc
+        (if *browser*
+            (ext::browse-url doc :out stream)
+            (format stream name doc))))))
+
 (clos:defgeneric describe-object (obj stream)
   (:method ((obj t) (stream stream))
     (ecase (type-of obj)
@@ -257,7 +261,7 @@ to print the corresponding values, or T for all of them.")
                    normal-printout)
                 (push pack accessible-packs)))))
         (when accessible-packs
-          (format stream (TEXT ", is accessible in ~:d package~:*~[~;~:;s~] ~{~A~^, ~}")
+          (format stream (TEXT ", is accessible in ~:d package~:p ~{~A~^, ~}")
                   (length accessible-packs)
                   (sort (mapcar #'package-name accessible-packs)
                         #'string<))))
@@ -317,6 +321,10 @@ to print the corresponding values, or T for all of them.")
             (format stream (TEXT "Documentation as a ~a:") ty)
             (terpri stream)
             (princ doc stream))))
+      (launch-doc obj 'ext::clhs ; change to sys::clhs when ext:clhs is finally removed
+                  stream (TEXT "~%ANSI Documentation is at~% ~S"))
+      (launch-doc obj 'sys::impnotes stream
+                  (TEXT "~%CLISP Documentation is at~% ~S"))
       (when moree
         (terpri stream)
         (format stream (TEXT "For more information, evaluate ~{~S~^ or ~}.")
@@ -371,7 +379,7 @@ to print the corresponding values, or T for all of them.")
                 (package-name obj))
         (let ((nicknames (package-nicknames obj)))
           (when nicknames
-            (format stream (TEXT ". It has ~:d nickname~:*~[~;~:;s~] ~{~A~^, ~}")
+            (format stream (TEXT ". It has ~:d nickname~:p ~{~A~^, ~}")
                     (length nicknames) nicknames)))
         (format stream (TEXT "."))
         (let ((use-list (package-use-list obj))
@@ -379,19 +387,19 @@ to print the corresponding values, or T for all of them.")
           (terpri stream)
           (format stream (TEXT "It "))
           (when use-list
-            (format stream (TEXT "imports the external symbols of ~:d package~:*~[~;~:;s~] ~{~A~^, ~} and ")
+            (format stream (TEXT "imports the external symbols of ~:d package~:p ~{~A~^, ~} and ")
                     (length use-list)
                     (mapcar #'package-name use-list)))
           (let ((L nil) (count 0)) ; maybe list all exported symbols
             (do-external-symbols (s obj) (push s L) (incf count))
             (format stream
-                    (TEXT "exports ~[no symbols~:;~:*~:d symbol~:*~[~;~:;s~]~]")
+                    (TEXT "exports ~[no symbols~:;~:*~:d symbol~:p~]")
                     count)
             (when (zerop *describe-nesting*)
               (format stream (TEXT "~{ ~S~^,~}")
                       (sort L #'string< :key #'symbol-name))))
           (if used-by-list
-            (format stream (TEXT " to ~:d package~:*~[~;~:;s~] ~{~A~^, ~}")
+            (format stream (TEXT " to ~:d package~:p ~{~A~^, ~}")
                     (length used-by-list)
                     (mapcar #'package-name used-by-list))
             (format stream (TEXT ", but no package uses these exports")))
@@ -416,7 +424,9 @@ to print the corresponding values, or T for all of them.")
                      (if case-sensitive-p
                        (format stream (TEXT "It is case-sensitive, but not case-inverted!"))
                        (format stream (TEXT "It is a traditional ANSI CL compatible package, but uses the symbols from the modern ~S!")
-                               (find-package "CS-COMMON-LISP")))))))))
+                               (find-package "CS-COMMON-LISP"))))))))
+        (launch-doc obj 'sys::impnotes stream
+                    (TEXT "~%CLISP Documentation is at~% ~S")))
       (format stream (TEXT "a deleted package."))))
   (:method ((obj hash-table) (stream stream))
     (let ((count (hash-table-count obj)))
@@ -544,7 +554,7 @@ to print the corresponding values, or T for all of them.")
     (terpri stream) ; blank line
     (if (memq obj *describe-done*)
       (format stream (TEXT "~A [see above]") objstring)
-      (let ((doc (gethash obj *documentation*)))
+      (let ((doc (and (symbolp obj) (get obj 'sys::doc))))
         (push obj *describe-done*)
         (format stream (TEXT "~A is ") objstring)
         (describe-object obj stream)
@@ -746,10 +756,10 @@ to print the corresponding values, or T for all of them.")
         (assert (= (parse-integer (nth 0 pieces) :radix 16) (char-code ch)))
         (values-list
          (append
-          (mapcar #'(lambda (x) (if (equal x "") nil x))
+          (mapcar #'(lambda (x) (if (equal x #1="") nil x))
                   (subseq pieces 1 12))
           (mapcar #'(lambda (x)
-                      (if (equal x "") nil
+                      (if (equal x #1#) nil
                           (code-char (parse-integer x :radix 16))))
                   (subseq pieces 12 15))))))))
 
